﻿using System;
using System.IO;
using System.Linq;
using System.Windows.Forms;

namespace PrintScreenNotificationCore
{

    static class Program
    {
        /// <summary>
        /// アプリケーションのメイン エントリ ポイントです。
        /// </summary>
        [STAThread]
        static void Main(string[] args)
        {
            // Register AUMID and COM server and activate (for Desktop Bridge apps, this no-ops)
            DesktopNotificationManagerCompat.RegisterAumidAndComServer<MyNotificationActivator>("WindowsNotifications.PrintScreenNotificationCore");
            DesktopNotificationManagerCompat.RegisterActivator<MyNotificationActivator>();
            System.Windows.Forms.Application.EnableVisualStyles();
            System.Windows.Forms.Application.SetCompatibleTextRenderingDefault(false);

            //引数 "-ToastActivated"
            string Targs = DesktopNotificationManagerCompat.TOAST_ACTIVATED_LAUNCH_ARG;
            //トースト表示用のフォルダチェック
            //2==フォルダチェックモード
            if (args.Contains("2"))
            {
                //起動引数で指定されたフォルダ管理者を取得
                string user = System.IO.File.GetAccessControl(args[1]).GetOwner(typeof(System.Security.Principal.NTAccount)).ToString();
                //フォルダ管理者がSYSTEMの時はエラーとして終了
                if(user == "NT AUTHORITY\\SYSTEM")
                {
                    Environment.Exit(1);
                }

                //起動引数で指定されたフォルダに書き込めるかテスト
                string hStrFile = @"" + args[1] + "\\FolderAccessChecker.dat";
                System.IO.FileStream hStream = null;
                try
                {
                    hStream = System.IO.File.Create(hStrFile);
                }
                catch (System.UnauthorizedAccessException)
                {
                    //書き込めなかったのでエラー
                    Environment.Exit(1);
                }

                //書き込めたのでファイルをクローズして削除
                if (hStream != null)
                {
                    hStream.Close();
                }
                File.Delete(hStrFile);
                //ファイルに書き込めるとして終了
                Environment.Exit(0);
            }
            //トースト表示本体
            //1==PrintScreen通知から起動された場合
            if (args.Contains("1") || args.Contains(Targs))
            {
                //トーストから起動されたかチェック
                if (args.Contains(Targs))
                {
                    Application.Run(new Form1()); //トーストから起動された場合
                }
                else
                {
                    Application.Run(new Form2()); //PrintScreen通知から起動された場合
                }
            }
            else
            {
                //起動引数なしの場合起動できませんとエラー表示
                MessageBox.Show(Properties.Resources.NotHostStarted);
            }
        }
    }
}